<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=no
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Syndikering mislykket: enten er den valgte datakilde utilgjengelig eller inneholder den ingen artikler.',
	'avis_echec_syndication_02' => 'Syndikering mislykket: får ikke forbindelse til den valgte datakilde.',

	// I
	'info_1_article_syndique' => '1 article syndiqué'
);

?>
